@@ -1,9 +1,9 @@
 package TAP::DOM;
-# git description: v0.12-1-g71d1cef
+# git description: v0.13-6-g319c024
 
 our $AUTHORITY = 'cpan:SCHWIGON';
-# ABSTRACT: TAP::DOM - TAP as Document Object Model.
-$TAP::DOM::VERSION = '0.13';
+# ABSTRACT: TAP as Document Object Model.
+$TAP::DOM::VERSION = '0.14';
 use 5.006;
 use strict;
 use warnings;
@@ -98,6 +98,7 @@ sub new {
         my %IGNORE      = map { $_ => 1 } @{$args{ignore}};
         my $IGNORELINES = $args{ignorelines};
         my $USEBITSETS  = $args{usebitsets};
+        my $DISABLE_GLOBAL_KV_DATA  = $args{disable_global_kv_data};
         delete $args{ignore};
         delete $args{ignorelines};
         delete $args{usebitsets};
@@ -183,7 +184,13 @@ sub new {
                         my ($key, $value) = ($1, $2);
                         $key =~ s/^\s+//; # strip leading  whitespace
                         $key =~ s/\s+$//; # strip trailing whitespace
-                        $document_data{$key} = $value;
+
+                        # Store "# Test-key: value" entries also as
+                        # 'kv_data' under their parent ok line.
+                        if ($lines[-1]->is_test) {
+                            $lines[-1]->{kv_data}{$key} = $value;
+                        }
+                        $document_data{$key} = $value unless $lines[-1]->is_test && $DISABLE_GLOBAL_KV_DATA;
                 }
 
                 # yaml and comments are taken as children of the line before
@@ -321,7 +328,7 @@ __END__
 
 =head1 NAME
 
-TAP::DOM - TAP::DOM - TAP as Document Object Model.
+TAP::DOM - TAP as Document Object Model.
 
 =head1 SYNOPSIS
 
@@ -724,7 +731,7 @@ Steffen Schwigon <ss5@renormalist.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by Steffen Schwigon.
+This software is copyright (c) 2017 by Steffen Schwigon.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
