@@ -1,7 +1,7 @@
 package TAP::DOM::Archive;
 our $AUTHORITY = 'cpan:SCHWIGON';
 # ABSTRACT: Handle TAP:Archive files
-$TAP::DOM::Archive::VERSION = '0.93.2';
+$TAP::DOM::Archive::VERSION = '0.14';
 use 5.006;
 use strict;
 use warnings;
@@ -12,31 +12,17 @@ sub new {
 
         my %args = (@_ == 1) ? %{$_[0]} : @_;
 
-        require TAP::DOM;
-
         # Drop arguments which don't make sense here and would confuse
         # TAP::Parser called via TAP::DOM later.
         delete $args{tap};
         delete $args{sources};
         delete $args{exec};
 
-        my %tap_dom_args = ();
-        foreach (@TAP::DOM::tap_dom_args) {
-            if (defined $args{$_}) {
-                $tap_dom_args{$_} = $args{$_};
-                delete $args{$_};
-            }
-        }
-
+        require TAP::DOM;
         my $tap_documents = _read_tap_from_archive(\%args);
-
         my $tap_dom_list  = {
             meta => $tap_documents->{meta},
-            dom  => [
-                map { TAP::DOM->new(tap => $_, %tap_dom_args) }
-                grep { defined $_ }
-                @{$tap_documents->{tap}}
-            ],
+            dom  => [ map { TAP::DOM->new(tap => $_) } @{$tap_documents->{tap}} ],
         };
         return bless $tap_dom_list, $class;
 }
@@ -49,7 +35,6 @@ sub _read_tap_from_archive
         require YAML::Tiny;
         require IO::String;
         require IO::Zlib;
-        require Scalar::Util;
 
         my $content;
         if ($args->{filecontent}) {
@@ -57,10 +42,7 @@ sub _read_tap_from_archive
         } else {
             $content = do {
                 local $/;
-                my $F = Scalar::Util::openhandle($args->{source});
-                if (!defined $F) {
-                    open $F, '<', $args->{source} or die 'Can not read '.$args->{source};
-                }
+                open my $F, '<', $args->{source} or die 'Can not read '.$args->{source};
                 <$F>
             };
         }
@@ -70,9 +52,7 @@ sub _read_tap_from_archive
         my $TARZ         = IO::Zlib->new($TARSTR, "rb");
         my $tar          = Archive::Tar->new($TARZ);
 
-        my ($meta_yml)   = grep { $tar->contains_file($_) } qw{meta.yml ./meta.yml};
-        my $meta         = YAML::Tiny::Load($tar->get_content($meta_yml));
-
+        my $meta         = YAML::Tiny::Load($tar->get_content("meta.yml"));
         my @tap_sections = map {
             # try different variants of filenames that meta.yml gave us
             my $f1 = $_;                  # original name as-is
@@ -110,7 +90,6 @@ TAP::DOM::Archive - Handle TAP:Archive files
  # Create a DOM from TAP archive file
  use TAP::DOM::Archive;
  my $tapdom = TAP::DOM::Archive->new( source => $taparchive_filename );
- my $tapdom = TAP::DOM::Archive->new( source => $taparchive_filehandle );
  print Dumper($tapdom);
 
 =head1 DESCRIPTION
@@ -162,7 +141,7 @@ Steffen Schwigon <ss5@renormalist.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021 by Steffen Schwigon.
+This software is copyright (c) 2017 by Steffen Schwigon.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
